package Nm6q_10;

import java.io.Serializable;
import java.security.MessageDigest;
/* compiled from: ByteString.kt */
/* loaded from: classes.dex */
public class FSaI4_7 implements Serializable, Comparable<FSaI4_7> {
    public static final KQgRr5e_0 KQgRr5e_0 = new KQgRr5e_0(null);

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public static final FSaI4_7 f326KQgRr5e_0 = Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0();

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public transient int f327KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public transient String f328KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final byte[] f329KQgRr5e_0;

    /* compiled from: ByteString.kt */
    /* loaded from: classes.dex */
    public static final class KQgRr5e_0 {
        public KQgRr5e_0() {
        }

        public final FSaI4_7 KQgRr5e_0(byte... bArr) {
            FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(bArr, "data");
            return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(bArr);
        }

        public final FSaI4_7 QxJ9d_1(String str) {
            FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(str, "$receiver");
            return Nm6q_10.XDsvEfm_26.KQgRr5e_0.QxJ9d_1(str);
        }

        public /* synthetic */ KQgRr5e_0(FSaI4_7.Xgtqvk_8.QxJ9d_1.Mqv2r_3 mqv2r_3) {
            this();
        }

        public final FSaI4_7 KQgRr5e_0(String str) {
            FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(str, "$receiver");
            return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(str);
        }
    }

    public FSaI4_7(byte[] bArr) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(bArr, "data");
        this.f329KQgRr5e_0 = bArr;
    }

    public static final FSaI4_7 KQgRr5e_0(byte... bArr) {
        return KQgRr5e_0.KQgRr5e_0(bArr);
    }

    public static final FSaI4_7 PGPF6hQ_2(String str) {
        return KQgRr5e_0.QxJ9d_1(str);
    }

    public static final FSaI4_7 QxJ9d_1(String str) {
        return KQgRr5e_0.KQgRr5e_0(str);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public final byte[] m162KQgRr5e_0() {
        return this.f329KQgRr5e_0;
    }

    public String Mqv2r_3() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.Mqv2r_3(this);
    }

    /* renamed from: PGPF6hQ_2  reason: collision with other method in class */
    public String m164PGPF6hQ_2() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m187QxJ9d_1(this);
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public final String m167QxJ9d_1() {
        return this.f328KQgRr5e_0;
    }

    public boolean equals(Object obj) {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this, obj);
    }

    public int hashCode() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.QxJ9d_1(this);
    }

    public String toString() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.PGPF6hQ_2(this);
    }

    public final int KQgRr5e_0() {
        return this.f327KQgRr5e_0;
    }

    /* renamed from: PGPF6hQ_2  reason: collision with other method in class */
    public FSaI4_7 m163PGPF6hQ_2() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m183KQgRr5e_0(this);
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public FSaI4_7 m166QxJ9d_1() {
        return KQgRr5e_0("SHA-256");
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public final void m159KQgRr5e_0(int i) {
        this.f327KQgRr5e_0 = i;
    }

    public final int PGPF6hQ_2() {
        return QxJ9d_1();
    }

    public byte QxJ9d_1(int i) {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this, i);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public final void m160KQgRr5e_0(String str) {
        this.f328KQgRr5e_0 = str;
    }

    /* renamed from: PGPF6hQ_2  reason: collision with other method in class */
    public byte[] m165PGPF6hQ_2() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m188QxJ9d_1(this);
    }

    public int QxJ9d_1() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public String m158KQgRr5e_0() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m184KQgRr5e_0(this);
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public byte[] m168QxJ9d_1() {
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m186KQgRr5e_0(this);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public FSaI4_7 m157KQgRr5e_0() {
        return KQgRr5e_0("SHA-1");
    }

    public FSaI4_7 KQgRr5e_0(String str) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(str, "algorithm");
        byte[] digest = MessageDigest.getInstance(str).digest(this.f329KQgRr5e_0);
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.KQgRr5e_0((Object) digest, "MessageDigest.getInstance(algorithm).digest(data)");
        return new FSaI4_7(digest);
    }

    public final byte KQgRr5e_0(int i) {
        return QxJ9d_1(i);
    }

    public void KQgRr5e_0(X6FRs_4 x6FRs_4) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(x6FRs_4, "buffer");
        byte[] bArr = this.f329KQgRr5e_0;
        x6FRs_4.KQgRr5e_0(bArr, 0, bArr.length);
    }

    public boolean KQgRr5e_0(int i, FSaI4_7 fSaI4_7, int i2, int i3) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(fSaI4_7, "other");
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this, i, fSaI4_7, i2, i3);
    }

    public boolean KQgRr5e_0(int i, byte[] bArr, int i2, int i3) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(bArr, "other");
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this, i, bArr, i2, i3);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public final boolean m161KQgRr5e_0(FSaI4_7 fSaI4_7) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(fSaI4_7, "prefix");
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.m185KQgRr5e_0(this, fSaI4_7);
    }

    @Override // java.lang.Comparable
    /* renamed from: KQgRr5e_0 */
    public int compareTo(FSaI4_7 fSaI4_7) {
        FSaI4_7.Xgtqvk_8.QxJ9d_1.IFxWkV_5.QxJ9d_1(fSaI4_7, "other");
        return Nm6q_10.XDsvEfm_26.KQgRr5e_0.KQgRr5e_0(this, fSaI4_7);
    }
}
